@@ -2,6 +2,10 @@ import configparser
 import re
 import csv
 import os
+import json
+import codecs
+import numpy
+import datetime
 from tqdm import tqdm
 
 
@@ -31,6 +35,43 @@ def read_config(conf_path):
     return conf_dict
 
 
+class MyEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, numpy.integer):
+            return int(obj)
+        elif isinstance(obj, numpy.floating):
+            return float(obj)
+        elif isinstance(obj, numpy.ndarray):
+            return obj.tolist()
+        elif isinstance(obj, bytes):
+            return str(obj, encoding='utf-8')
+        elif isinstance(obj, datetime.datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+        elif isinstance(obj, datetime.date):
+            return obj.strftime('%Y-%m-%d')
+        else:
+            return super(MyEncoder, self).default(obj)
+
+def write_json(filename, res, isIndent=False, isLine=False):
+    if not isLine and (isinstance(res, dict) or isinstance(res, list)):
+        if isIndent:
+            json_str = json.dumps(res, ensure_ascii=False, indent=4, cls=MyEncoder)
+            with open(filename, 'w', encoding='utf-8') as json_file:
+                json_file.write(json_str)
+        else:
+            json_str = json.dumps(res, ensure_ascii=False, cls=MyEncoder)
+            with open(filename, 'w', encoding='utf-8') as json_file:
+                json_file.write(json_str)
+    else:
+        with codecs.open(filename, 'w', 'utf-8') as f:
+            for formatted_instance in res:
+                json_str = json.dumps(formatted_instance, ensure_ascii=False, cls=MyEncoder)
+                f.write(json_str)
+                f.write('\n')
+        f.close()
+
+
+
 def check_and_creat_dir(file_url):
     '''
     判断文件目录是否存在，文件目录不存在则创建目录
